#
# spec file for package libfdatetime
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libfdatetime
%define lname	libfdatetime1
Version:        20240415
Release:        1.5
Summary:        A library for date and time data types
License:        LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/libyal/libfdatetime
Source:         https://github.com/libyal/libfdatetime/releases/download/%version/libfdatetime-alpha-%version.tar.gz
Source2:        https://github.com/libyal/libfdatetime/releases/download/%version/libfdatetime-alpha-%version.tar.gz.asc
Source3:        %name.keyring
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libcerror) >= 20240413
# Various notes: https://en.opensuse.org/libyal

%description
A library for date and time data types. Part of the libyal family of libraries.

%package -n %lname
Summary:        A library for date and time data types
Group:          System/Libraries

%description -n %lname
A library for date and time data types. Part of the libyal family of libraries.

%package devel
Summary:        Development files for libfdatetime, a date and time data type library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
A library for date and time data types.

This subpackage contains libraries and header files for developing
applications that want to make use of libfdatetime.

%prep
%autosetup -p1

%build
echo "V_%version { global: *; };" >v.sym
%configure --disable-static LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep '  local' config.log && exit 1
%make_build

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%ldconfig_scriptlets -n %lname

%files -n %lname
%license COPYING*
%_libdir/libfdatetime.so.1*

%files devel
%_includedir/libfdatetime*
%_libdir/libfdatetime.so
%_libdir/pkgconfig/libfdatetime.pc
%_mandir/man3/libfdatetime.3*

%changelog
* Mon Apr 15 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240415
  * No changelog was provided
* Mon Jan 15 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240115
  * No user-visible changes
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Mon Jan 17 2022 Jan Engelhardt <jengelh@inai.de>
- Force autoreconf rerun due to patch presence
* Wed Jan 12 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220112
  * No changes, version bump only.
* Wed May 12 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210414 (da968c35)
  * No changelog was provided
- Add system-libs.patch
* Mon Apr 15 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20180910
  * Worked on POSIX timestamp in nanoseconds
  * Worked on floatingtime
* Sun Oct  1 2017 Greg.Freemyer@gmail.com
- update to v0~20170902
  * applied 2017 updates
  * worked on tests
  * improved handling of strings with invalid syntax
* Wed Jan 27 2016 Greg.Freemyer@gmail.com
- update to v0~20150507
  * fix in POSIX timestamp for missing sign check
* Thu Jan  8 2015 Greg.Freemyer@gmail.com
- update to v0~20150104
  * 2015 update - minimal changes
- update URL to the new github site
- replace Source: field with fully defined URL
- remove DL-URL comment
- start using libcstring from OBS, not internal version
* Thu Aug 14 2014 Greg.Freemyer@gmail.com
- update to 0~20140105
  * 2014 update
  * updated dependencies
  * added copy to int functions
* Thu Nov 21 2013 Greg.Freemyer@gmail.com
- update to 0~20130904
  * code clean up
  * worked on tests
  * updated dependencies
  * textual changes
  * maximum string size is now only returned for invalid date time values
- change compression to gz to simplify updates
* Tue Jul 30 2013 Greg.Freemyer@gmail.com
- cleanup specfile comments
* Mon Apr 22 2013 Greg.Freemyer@gmail.com
- ran spec-cleaner
* Thu Apr  4 2013 jengelh@inai.de
- Initial package (version 0~20130317) for build.opensuse.org
